// 打印类型
enum printTypeEnum {
  USB, // usb打印
  NETWORK // 网络打印
}

// 连接信息
interface Connection {
  printType?: printTypeEnum // 打印类型
  socketIp?: string // socket Ip
  socketPort?: string // socket 端口
  networkIp?: string // 网络打印Ip
  networkPort?: string // 网络打印端口
}

// 标签类型枚举
enum sensorEnum {
  GAP,
  BLINE
}

// 打印机纸张信息
interface Paper {
  width: number // 标签宽度(单位mm)
  height: number // 标签高度(单位mm)
  gapHeight: number // 间隙高度(单位mm)
  speed?: number // 打印速度(单位mm)
  density?: number // 打印浓度 0~15 默认为 8
  sensor?: sensorEnum // 标签类型["0":GAP, "1":BLINE]
  gapOffset?: number // 间隙偏移(单位mm)
}

// 打印机命令数据
interface SendData {
  usb_list?: object[]
  about?: object[]
  functions_inorder?: object[]
}

// 打印数量
interface LabelQuantity {
  sets: number // 打印份数
  copies?: number // 打印张数 默认 1
}

// 条形码信息
interface BarCodeModel {
  x: number		// 条码x轴座标(单位mm)
  y: number		// 条码y轴座标(单位mm)
  height: number		// 条码高度(单位mm)
  narrow: number		// 条码窄元件宽度[详见TSPL手册BARCODE条目](单位mm)
  wide: number			// 条码宽元件宽度[详见TSPL手册BARCODE条目](单位mm)
  code: string			// 条码内容
  type?: string		// 条码类型["128", "128M", "EAN128", "25", "25C", "39", "39C", "93", "EAN13", "EAN13+2", "EAN13+5", "EAN8", "EAN8+2", "EAN8+5", "CODA", "POST", "UPCA", "UPCA+2", "UPCA+5", "UPCE", "UPCE+2", "UPCE+5", "CPOST", "MSI", "MSIC", "PLESSEY", "ITF14", "EAN14", "11", "TELEPEN", "TELEPENN", "PLANET", "CODE49", "DPI", "DPL"]
  readable?: number		// 条码码文位置["0":无, "1":置左, "2":置中, "3":置右] 默认 2
  rotation?: number		// 条码旋转["0":无, "90":90度, "180":180度, "270":270度] 默认 0
}

// 二维码信息
interface QrCodeModel {
  x: number		// 二维码x轴座标(单位mm)
  y: number		// 二维码y轴座标(单位mm)
  cellWidth: number		// 二维码宽度 1~10
  content: string			// 二维码内容
  mask?: string			// S0~S8, 默认为 S7
  eccLevel?: string		// 纠错等级 L : 7% M : 15% Q : 25% H : 30% 默认 Q
  mode?: string		// 自动 / 手动编码 A : 自动  M : 手动 默认 A
  rotation?: number		// 条码旋转["0":无, "90":90度, "180":180度, "270":270度] 默认 0
  model?: string		// M1: , 原始版本 M2: 扩大版本 (大部分的智能手机支持此版本) 默认 M2
}


// 文字信息
interface FontModel {
  x: number		// 文字x轴座标(单位mm)
  y: number		// 文字y轴座标(单位mm)
  fontheight: number		// 文字大小(单位mm)
  text: string			// 需要打印的文字
  rotation?: number		// 文字旋转["0":无, "90":90度, "180":180度, "270":270度] 默认 0
  fontstyle?: number		// 文字样式["0":无, "1":斜体, "2":粗体, "3":斜体+粗体] 默认 0
  fontunderline?: number // 文字底线["0":无, "1":底线] 默认 0
  szFaceName?: string		// 字型名称[例:"Arial"] 默认 Arial
}

export { BarCodeModel, Connection, FontModel, LabelQuantity, Paper, QrCodeModel, SendData };
